@@ -1,17 +1,35 @@
+//! Handles configuration for the Compiler Interrupts library.
+
 use cargo_util::paths;
 use serde::{Deserialize, Serialize};
 use tracing::{debug, info};
 
 use crate::{util, CIResult};
 
-#[derive(Serialize, Deserialize, Default)]
+/// Configuration for the Compiler Interrupts library.
+#[derive(Serialize, Deserialize, Default, Debug)]
 pub struct Config {
+    /// Path to the library.
     pub library_path: String,
+
+    /// Path to the debug-enabled library.
+    pub library_path_dbg: String,
+
+    /// LLVM version used to compile the library.
     pub llvm_version: String,
+
+    /// Default arguments.
     pub default_args: Vec<String>,
+
+    /// Checksum of the source code.
+    pub checksum: String,
+
+    /// Remote URL for the source code.
+    pub url: String,
 }
 
 impl Config {
+    /// Load the configuration.
     pub fn load() -> CIResult<Config> {
         let mut path = util::config_path()?;
         path.push("default.cfg");
@@ -30,8 +48,8 @@ impl Config {
                 paths::copy(&path, &old_path)?;
                 Config::save(&Config::default())?;
 
-                eprintln!("broken config file found, replaced with default config");
-                eprintln!("old config file can be found at: {}\n", old_path.display());
+                eprintln!("Incompatible config file found, replaced with default config");
+                eprintln!("Old config file can be found at: {}", old_path.display());
                 debug!("error: {}", e);
 
                 Config::load()
@@ -39,6 +57,7 @@ impl Config {
         }
     }
 
+    /// Save the configuration.
     pub fn save(config: &Config) -> CIResult<()> {
         let mut path = util::config_path()?;
         path.push("default.cfg");
